def login(
    page,
    config_data: dict,
) -> None:
    landing_page: str = config_data["landing_page"]
    navid: str = config_data["navid"]
    page.goto(landing_page)

    # Ensure the element is visible and clickable
    try:
        login_button = page.wait_for_selector(
            "#logIn_btn", timeout=10000
        )  # Wait up to 10 seconds
        if login_button:
            login_button.click()
    except Exception as e:
        print(f"An error occurred: {e}")
        exit(1)

    try:
        # Fill out the form with your credentials
        username_input = page.query_selector("#Username")
        password_input = page.query_selector("#Password")

        if username_input and password_input:
            username_input.fill(config_data["username"])
            password_input.fill(config_data["password"])

            # Click the login button
            login_button = page.query_selector("#login-button")
            if login_button:
                login_button.click()
                print("Login attempt successful.")
            else:
                print("The login button was not found.")
        else:
            print("One or both of the input fields were not found.")
    except Exception as e:
        print(f"An error occurred: {e}")
        exit(1)

    # Wait for the evaluation link to become visible and then click on it
    try:
        login_button = page.wait_for_selector(
            f"a.depth_1.{navid}.navLink", timeout=10000
        )  # Wait up to 10 seconds
        if login_button:
            login_button.click()
        print("Evaluation link clicked.")
    except Exception as e:
        print(f"An error occurred: {e}")
        exit(1)

    # We wait until the selector is available
    try:
        page.wait_for_selector(
            "div.inputFieldLabel", timeout=10000
        )  # Wait up to 10 seconds
    except Exception as e:
        print(f"An error occurred: {e}")
        exit(1)
